pub struct MetaClient {
id: Id,
channel_manager: ChannelManager,
leader_provider_factory: Arc<dyn LeaderProviderFactory>,
heartbeat: Option<Client>,
config: Option<Client>,
store: Option<Client>,
procedure: Option<Client>,
cluster: Option<Client>,
region_follower: Option<RegionFollowerClientRef>,
}Fields
id: Idchannel_manager: ChannelManagerleader_provider_factory: Arc<dyn LeaderProviderFactory>heartbeat: Option<Client>config: Option<Client>store: Option<Client>procedure: Option<Client>cluster: Option<Client>region_follower: Option<RegionFollowerClientRef>Implementations
Sourceimpl MetaClient
impl MetaClient
pub async fn start<U, A>(&mut self, urls: A) -> Result<()>
Sourcepub(crate) async fn start_with<U, A>(
&mut self,
leader_provider: LeaderProviderRef,
peers: A,
) -> Result<()>
pub(crate) async fn start_with<U, A>( &mut self, leader_provider: LeaderProviderRef, peers: A, ) -> Result<()>
Start the client with a LeaderProvider and other Metasrv peers’ addresses.
Sourcepub async fn ask_leader(&self) -> Result<String>
pub async fn ask_leader(&self) -> Result<String>
Ask the leader address of metasrv, and the heartbeat component
needs to create a bidirectional streaming to the leader.
pub async fn pull_config<T, U>(&self, deserializer: T) -> Result<U>where
T: PluginOptionsDeserializer<U>,
U: DeserializeOwned,
Sourcepub async fn heartbeat(
&self,
) -> Result<(HeartbeatSender, HeartbeatStream, HeartbeatConfig)>
pub async fn heartbeat( &self, ) -> Result<(HeartbeatSender, HeartbeatStream, HeartbeatConfig)>
Returns a heartbeat bidirectional streaming: (sender, receiver), the
other end is the leader of metasrv.
The datanode needs to use the sender to continuously send heartbeat
packets (some self-state data), and the receiver can receive a response
from “metasrv” (which may contain some scheduling instructions).
Returns the heartbeat sender, stream, and configuration received from Metasrv.
Sourcepub async fn range(&self, req: RangeRequest) -> Result<RangeResponse>
pub async fn range(&self, req: RangeRequest) -> Result<RangeResponse>
Range gets the keys in the range from the key-value store.
Sourcepub async fn put(&self, req: PutRequest) -> Result<PutResponse>
pub async fn put(&self, req: PutRequest) -> Result<PutResponse>
Put puts the given key into the key-value store.
Sourcepub async fn batch_get(&self, req: BatchGetRequest) -> Result<BatchGetResponse>
pub async fn batch_get(&self, req: BatchGetRequest) -> Result<BatchGetResponse>
BatchGet atomically get values by the given keys from the key-value store.
Sourcepub async fn batch_put(&self, req: BatchPutRequest) -> Result<BatchPutResponse>
pub async fn batch_put(&self, req: BatchPutRequest) -> Result<BatchPutResponse>
BatchPut atomically puts the given keys into the key-value store.
Sourcepub async fn batch_delete(
&self,
req: BatchDeleteRequest,
) -> Result<BatchDeleteResponse>
pub async fn batch_delete( &self, req: BatchDeleteRequest, ) -> Result<BatchDeleteResponse>
BatchDelete atomically deletes the given keys from the key-value store.
Sourcepub async fn compare_and_put(
&self,
req: CompareAndPutRequest,
) -> Result<CompareAndPutResponse>
pub async fn compare_and_put( &self, req: CompareAndPutRequest, ) -> Result<CompareAndPutResponse>
CompareAndPut atomically puts the value to the given updated value if the current value == the expected value.
Sourcepub async fn delete_range(
&self,
req: DeleteRangeRequest,
) -> Result<DeleteRangeResponse>
pub async fn delete_range( &self, req: DeleteRangeRequest, ) -> Result<DeleteRangeResponse>
DeleteRange deletes the given range from the key-value store.
Sourcepub async fn query_procedure_state(
&self,
pid: &str,
) -> Result<ProcedureStateResponse>
pub async fn query_procedure_state( &self, pid: &str, ) -> Result<ProcedureStateResponse>
Query the procedure state by its id.
Sourcepub async fn migrate_region(
&self,
request: MigrateRegionRequest,
) -> Result<MigrateRegionResponse>
pub async fn migrate_region( &self, request: MigrateRegionRequest, ) -> Result<MigrateRegionResponse>
Submit a region migration task.
Sourcepub async fn reconcile(
&self,
request: ReconcileRequest,
) -> Result<ReconcileResponse>
pub async fn reconcile( &self, request: ReconcileRequest, ) -> Result<ReconcileResponse>
Reconcile the procedure state.
Sourcepub async fn gc_regions(&self, request: GcRegionsRequest) -> Result<GcResponse>
pub async fn gc_regions(&self, request: GcRegionsRequest) -> Result<GcResponse>
Manually trigger GC for specific regions.
Sourcepub async fn gc_table(&self, request: GcTableRequest) -> Result<GcResponse>
pub async fn gc_table(&self, request: GcTableRequest) -> Result<GcResponse>
Manually trigger GC for a table (all its regions).
Sourcepub async fn submit_ddl_task(
&self,
req: SubmitDdlTaskRequest,
) -> Result<SubmitDdlTaskResponse>
pub async fn submit_ddl_task( &self, req: SubmitDdlTaskRequest, ) -> Result<SubmitDdlTaskResponse>
Submit a DDL task
pub fn heartbeat_client(&self) -> Result<HeartbeatClient>
pub fn config_client(&self) -> Result<ConfigClient>
pub fn store_client(&self) -> Result<StoreClient>
pub fn procedure_client(&self) -> Result<ProcedureClient>
pub fn cluster_client(&self) -> Result<ClusterClient>
pub fn channel_config(&self) -> &ChannelConfig
pub fn id(&self) -> Id